@@ -1,3 +1,5 @@
 from bmtk.simulator.filternet.lgnmodel.temporalfilter import *
 from bmtk.simulator.filternet.lgnmodel.spatialfilter import *
-from bmtk.simulator.filternet.lgnmodel.linearfilter import *
\ No newline at end of file
+from bmtk.simulator.filternet.lgnmodel.linearfilter import *
+from bmtk.simulator.filternet.lgnmodel.waveletfilter import *
+from bmtk.simulator.filternet.lgnmodel.gaborfilter import *
\ No newline at end of file
