@@ -6,10 +6,11 @@ from bmtk.simulator.filternet.io_tools import io
 
 class Movie(object):
     def __init__(self, data, row_range=None, col_range=None, labels=('time', 'y', 'x'),
-                 units=('second', 'pixel', 'pixel'), frame_rate=None, t_range=None):
+                 units=('second', 'pixel', 'pixel'), frame_rate=None, t_range=None, padding=False):
         self.data = data
         self.labels = labels
         self.units = units
+        self.padding=padding
         assert(units[0] == 'second')
 
         if t_range is None:
@@ -253,7 +254,7 @@ class GratingMovie(Movie):
         self.frame_rate = float(frame_rate)  # in Hz
 
     def create_movie(self, t_min=0, t_max=1, gray_screen_dur=0, cpd=0.05, temporal_f=4, theta=45,
-                     phase=0., contrast=1.0, row_size_new=None, col_size_new=None):
+                     phase=0., contrast=1.0, degrees_per_pixel=None, row_size_new=None, col_size_new=None):
         """Create the grating movie with the desired parameters
 
         :param t_min: start time in seconds
@@ -264,6 +265,7 @@ class GratingMovie(Movie):
         :param theta: orientation angle, in degrees
         :param phase: temporal phase, in degrees
         :param contrast: the maximum constrast, must be between 0 and 1.0
+        :param degrees_per_pixel: pixel pitch of the movie in degrees (default (if None) is 1.0/(cpd*10))
         :param row_size_new: Use to truncate screen, by default leaves original row dimension
         :param col_size_new: Use to truncate screen, by default leaves original col dimension
         :return: Movie object of grating with desired parameters
@@ -271,9 +273,10 @@ class GratingMovie(Movie):
         assert contrast <= 1, "Contrast must be <= 1"
         assert contrast > 0, "Contrast must be > 0"
 
-        physical_spacing = 1.0 / (float(cpd) * 10)  # To make sure no aliasing occurs
-        self.row_range = np.linspace(0, self.row_size, int(self.row_size/physical_spacing), endpoint=True)
-        self.col_range = np.linspace(0, self.col_size, int(self.col_size/physical_spacing), endpoint=True)
+        if degrees_per_pixel is None:  # default behavior when not specified
+            degrees_per_pixel = 1.0 / (float(cpd) * 10)  # To make sure no aliasing occurs
+        self.row_range = np.linspace(0, self.row_size, int(self.row_size/degrees_per_pixel), endpoint=True)
+        self.col_range = np.linspace(0, self.col_size, int(self.col_size/degrees_per_pixel), endpoint=True)
         numberFramesNeeded = int(round(self.frame_rate * (t_max - gray_screen_dur))) + 1
         time_range = np.linspace(0, t_max - gray_screen_dur, numberFramesNeeded, endpoint=True)
 
@@ -316,9 +319,9 @@ class LoomingMovie(Movie):
         :param t_looming: duration of time looming
         :param gray_screen_dur:
         """
-        physical_spacing = 1.0  # To make sure no aliasing occurs
-        self.row_range = np.linspace(0, self.row_size, int(self.row_size/physical_spacing), endpoint=True)
-        self.col_range = np.linspace(0, self.col_size, int(self.col_size/physical_spacing), endpoint=True)
+        degrees_per_pixel = 1.0  # To make sure no aliasing occurs
+        self.row_range = np.linspace(0, self.row_size, int(self.row_size/degrees_per_pixel), endpoint=True)
+        self.col_range = np.linspace(0, self.col_size, int(self.col_size/degrees_per_pixel), endpoint=True)
         loomingFramesNeeded = int(round(self.frame_rate * t_looming))
         grayScreenFrames = int(round(self.frame_rate * gray_screen_dur))
         time_range = np.linspace(0, t_looming, loomingFramesNeeded, endpoint=True)
