@@ -1,4 +1,6 @@
 from .record_spikes import SpikesMod
 from .multimeter_reporter import MultimeterMod
 from .iclamp import IClampMod
-from .ecephys_module import PointECEphysUnitsModule
\ No newline at end of file
+from .ecephys_module import PointECEphysUnitsModule
+from .spikes_inputs import SpikesInputsMod
+from .weight_recorder import WeightRecorder
