@@ -280,7 +280,6 @@ class SaveSynapses(SimReport):
 
 @SimReport.register_module
 class MultimeterReport(MembraneReport):
-
     @staticmethod
     def avail_modules():
         return ['multimeter', 'multimeter_report']
@@ -293,6 +292,26 @@ class NetconReport(MembraneReport):
         return ['netcon_report']
 
 
+@SimReport.register_module
+class WeightRecorder(SimReport):
+    @staticmethod
+    def avail_modules():
+        return 'weight_recorder'
+   
+    def _get_defaults(self):
+        output_dir = self.params.get('output_dir', self.default_dir)
+
+        file_name = self.params.get('file_name', None)
+        if file_name is None:
+            file_name = os.path.join(output_dir, '{}.csv'.format(self.report_name))
+        elif os.path.isabs(file_name):
+            file_name = file_name           
+        else:
+            file_name = os.path.join(output_dir, file_name)
+
+        return [('file_name', file_name), ('output_dir', output_dir), ('clean_temp_file', True)]
+
+
 def from_config(cfg):
     SimReport.default_dir = cfg.output_dir
 
